@@ -38,6 +38,9 @@
 
   
    HISTORY: 
+   2008-06-22 : 2.4.8      - fixed too small allocation of postprocessing string,
+                             corrected typo in the config file documentation,
+                             update for the SELinux .te-file in contrib/
    2008-03-24 : 2.4.7      - corrected the exit codes to match CUPS' specifications,
                              unmodified username passed to PostProcessing as 3rd arg,
                              made PPD file auto-selectable via IEEE-1284 device id
@@ -807,7 +810,7 @@ int main(int argc, char *argv[]) {
     log_event(CPDEBUG, "file mode set for user output", outfile);
     
     if (strlen(conf.postprocessing)) {
-      size=strlen(conf.postprocessing)+strlen(outfile)+strlen(passwd->pw_name)+strlen(argv[2])+3;
+      size=strlen(conf.postprocessing)+strlen(outfile)+strlen(passwd->pw_name)+strlen(argv[2])+4;
       ppcall=calloc(size, sizeof(char));
       if (ppcall == NULL) 
         log_event(CPERROR, "failed to allocate memory for postprocessing (non fatal)", NULL);
